pub struct ActorMeshRef<A: Referable> { /* private fields */ }Expand description
A reference to a stable snapshot of an ActorMesh.
Implementations
Sourceimpl<A: Referable> ActorMeshRef<A>
impl<A: Referable> ActorMeshRef<A>
Sourcepub fn cast<M>(&self, cx: &impl Actor, message: M) -> Result<()>
pub fn cast<M>(&self, cx: &impl Actor, message: M) -> Result<()>
Cast a message to all the actors in this mesh
Sourcepub fn cast_with_headers<M>(
&self,
cx: &impl Actor,
caller_headers: &Flattrs,
message: M,
) -> Result<()>
pub fn cast_with_headers<M>( &self, cx: &impl Actor, caller_headers: &Flattrs, message: M, ) -> Result<()>
Cast a message to all the actors in this mesh, merging
caller-supplied caller_headers into the per-rank envelope
headers before send. Used to propagate caller-known context
(e.g. operation-context keys marked with OPERATION_CONTEXT_HEADER)
onto the outgoing request so receivers can project it back
onto replies.
Sourcepub fn cast_choose_with_headers<M>(
&self,
cx: &impl Actor,
caller_headers: &Flattrs,
message: M,
) -> Result<()>
pub fn cast_choose_with_headers<M>( &self, cx: &impl Actor, caller_headers: &Flattrs, message: M, ) -> Result<()>
Cast a message to one randomly chosen actor in this mesh, merging
caller-supplied caller_headers into the outgoing envelope.
pub fn id(&self) -> &ActorMeshId
pub fn controller(&self) -> &Option<ActorRef<ActorMeshController<A>>>
Sourcepub async fn next_supervision_event(
&self,
cx: &impl Actor,
) -> Result<MeshFailure, Error>
pub async fn next_supervision_event( &self, cx: &impl Actor, ) -> Result<MeshFailure, Error>
Returns the next supervision event occurring on this mesh. Await this simultaneously with the return result of a message (such as awaiting a reply after a cast) to get back a message that indicates the actor that failed, instead of waiting forever for a reply. If there are multiple simultaneous awaits of next_supervision_event, all of them will receive the same event.
Sourcepub fn clone_with_supervision_receiver(&self) -> Self
pub fn clone_with_supervision_receiver(&self) -> Self
Same as Clone, but includes a shared supervision receiver. This copy will share the same health state and get the same supervision events. Will have a separate cache.